# Music Player GUI using Python Tkinter

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 
[![Python 3.7](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)   


## Usage

- Make sure you have Python installed in your system.
- Run Following command in the CMD.
 ```
  pip install text_clean
  ```
## Example

 ```

  ```

## Run the following Script.
 ```
  python test.py
 ```


